# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .bad_request_error_body import BadRequestErrorBody
from .content_too_large_error_body import ContentTooLargeErrorBody
from .forbidden_error_body import ForbiddenErrorBody
from .gateway_timeout_error_body import GatewayTimeoutErrorBody
from .get_v_10_asn_whois_response import GetV10AsnWhoisResponse
from .get_v_10_asn_whois_response_administrative_contacts_item import GetV10AsnWhoisResponseAdministrativeContactsItem
from .get_v_10_asn_whois_response_as_blocks_item import GetV10AsnWhoisResponseAsBlocksItem
from .get_v_10_asn_whois_response_aut_nums_item import GetV10AsnWhoisResponseAutNumsItem
from .get_v_10_asn_whois_response_organization import GetV10AsnWhoisResponseOrganization
from .get_v_10_asn_whois_response_technical_contacts_item import GetV10AsnWhoisResponseTechnicalContactsItem
from .get_v_10_domain_availability_response import GetV10DomainAvailabilityResponse
from .get_v_10_domain_availability_response_domain_available_response_item import (
    GetV10DomainAvailabilityResponseDomainAvailableResponseItem,
)
from .get_v_10_ip_whois_response import GetV10IpWhoisResponse
from .get_v_10_ip_whois_response_abuse_contacts_item import GetV10IpWhoisResponseAbuseContactsItem
from .get_v_10_ip_whois_response_inet_nums_item import GetV10IpWhoisResponseInetNumsItem
from .get_v_10_ip_whois_response_organization import GetV10IpWhoisResponseOrganization
from .get_v_10_ip_whois_response_technical_contacts_item import GetV10IpWhoisResponseTechnicalContactsItem
from .get_v_10_ssl_live_response import GetV10SslLiveResponse
from .get_v_10_ssl_live_response_ssl_certificates_item import GetV10SslLiveResponseSslCertificatesItem
from .get_v_10_ssl_live_response_ssl_certificates_item_extensions import (
    GetV10SslLiveResponseSslCertificatesItemExtensions,
)
from .get_v_10_ssl_live_response_ssl_certificates_item_extensions_authority_info_access import (
    GetV10SslLiveResponseSslCertificatesItemExtensionsAuthorityInfoAccess,
)
from .get_v_10_ssl_live_response_ssl_certificates_item_extensions_certificate_policies_item import (
    GetV10SslLiveResponseSslCertificatesItemExtensionsCertificatePoliciesItem,
)
from .get_v_10_ssl_live_response_ssl_certificates_item_extensions_subject_alternative_names import (
    GetV10SslLiveResponseSslCertificatesItemExtensionsSubjectAlternativeNames,
)
from .get_v_10_ssl_live_response_ssl_certificates_item_issuer import GetV10SslLiveResponseSslCertificatesItemIssuer
from .get_v_10_ssl_live_response_ssl_certificates_item_public_key import (
    GetV10SslLiveResponseSslCertificatesItemPublicKey,
)
from .get_v_10_ssl_live_response_ssl_certificates_item_subject import GetV10SslLiveResponseSslCertificatesItemSubject
from .get_v_10_whois_response import GetV10WhoisResponse
from .get_v_10_whois_response_registry_data import GetV10WhoisResponseRegistryData
from .get_v_10_whois_response_status import GetV10WhoisResponseStatus
from .get_v_10_whois_response_whois_domains_historical_item import GetV10WhoisResponseWhoisDomainsHistoricalItem
from .get_v_10_whois_response_whois_domains_historical_item_registry_data import (
    GetV10WhoisResponseWhoisDomainsHistoricalItemRegistryData,
)
from .get_v_20_dns_historical_response import GetV20DnsHistoricalResponse
from .get_v_20_dns_historical_response_historical_dns_records_item import (
    GetV20DnsHistoricalResponseHistoricalDnsRecordsItem,
)
from .get_v_20_dns_historical_response_historical_dns_records_item_dns_records_item import (
    GetV20DnsHistoricalResponseHistoricalDnsRecordsItemDnsRecordsItem,
)
from .get_v_20_dns_live_response import GetV20DnsLiveResponse
from .get_v_20_dns_live_response_dns_records_item import GetV20DnsLiveResponseDnsRecordsItem
from .get_v_21_dns_reverse_response import GetV21DnsReverseResponse
from .get_v_21_dns_reverse_response_reverse_dns_records_item import GetV21DnsReverseResponseReverseDnsRecordsItem
from .get_v_21_dns_reverse_response_reverse_dns_records_item_dns_records_item import (
    GetV21DnsReverseResponseReverseDnsRecordsItemDnsRecordsItem,
)
from .get_v_21_dns_reverse_response_reverse_dns_records_item_dns_types import (
    GetV21DnsReverseResponseReverseDnsRecordsItemDnsTypes,
)
from .internal_server_error_body import InternalServerErrorBody
from .not_found_error_body import NotFoundErrorBody
from .post_v_10_bulkwhois_response import PostV10BulkwhoisResponse
from .post_v_10_bulkwhois_response_bulk_whois_response_item import PostV10BulkwhoisResponseBulkWhoisResponseItem
from .post_v_10_bulkwhois_response_bulk_whois_response_item_domain_registrar import (
    PostV10BulkwhoisResponseBulkWhoisResponseItemDomainRegistrar,
)
from .post_v_10_bulkwhois_response_bulk_whois_response_item_registrant_contact import (
    PostV10BulkwhoisResponseBulkWhoisResponseItemRegistrantContact,
)
from .post_v_20_dns_bulk_live_response import PostV20DnsBulkLiveResponse
from .post_v_20_dns_bulk_live_response_bulk_dns_info_item import PostV20DnsBulkLiveResponseBulkDnsInfoItem
from .post_v_20_dns_bulk_live_response_bulk_dns_info_item_dns_records_item import (
    PostV20DnsBulkLiveResponseBulkDnsInfoItemDnsRecordsItem,
)
from .post_v_20_dns_bulk_live_response_bulk_dns_info_item_dns_types import (
    PostV20DnsBulkLiveResponseBulkDnsInfoItemDnsTypes,
)
from .precondition_failed_error_body import PreconditionFailedErrorBody
from .request_timeout_error_body import RequestTimeoutErrorBody
from .service_unavailable_error_body import ServiceUnavailableErrorBody
from .too_many_requests_error_body import TooManyRequestsErrorBody
from .unauthorized_error_body import UnauthorizedErrorBody

__all__ = [
    "BadRequestErrorBody",
    "ContentTooLargeErrorBody",
    "ForbiddenErrorBody",
    "GatewayTimeoutErrorBody",
    "GetV10AsnWhoisResponse",
    "GetV10AsnWhoisResponseAdministrativeContactsItem",
    "GetV10AsnWhoisResponseAsBlocksItem",
    "GetV10AsnWhoisResponseAutNumsItem",
    "GetV10AsnWhoisResponseOrganization",
    "GetV10AsnWhoisResponseTechnicalContactsItem",
    "GetV10DomainAvailabilityResponse",
    "GetV10DomainAvailabilityResponseDomainAvailableResponseItem",
    "GetV10IpWhoisResponse",
    "GetV10IpWhoisResponseAbuseContactsItem",
    "GetV10IpWhoisResponseInetNumsItem",
    "GetV10IpWhoisResponseOrganization",
    "GetV10IpWhoisResponseTechnicalContactsItem",
    "GetV10SslLiveResponse",
    "GetV10SslLiveResponseSslCertificatesItem",
    "GetV10SslLiveResponseSslCertificatesItemExtensions",
    "GetV10SslLiveResponseSslCertificatesItemExtensionsAuthorityInfoAccess",
    "GetV10SslLiveResponseSslCertificatesItemExtensionsCertificatePoliciesItem",
    "GetV10SslLiveResponseSslCertificatesItemExtensionsSubjectAlternativeNames",
    "GetV10SslLiveResponseSslCertificatesItemIssuer",
    "GetV10SslLiveResponseSslCertificatesItemPublicKey",
    "GetV10SslLiveResponseSslCertificatesItemSubject",
    "GetV10WhoisResponse",
    "GetV10WhoisResponseRegistryData",
    "GetV10WhoisResponseStatus",
    "GetV10WhoisResponseWhoisDomainsHistoricalItem",
    "GetV10WhoisResponseWhoisDomainsHistoricalItemRegistryData",
    "GetV20DnsHistoricalResponse",
    "GetV20DnsHistoricalResponseHistoricalDnsRecordsItem",
    "GetV20DnsHistoricalResponseHistoricalDnsRecordsItemDnsRecordsItem",
    "GetV20DnsLiveResponse",
    "GetV20DnsLiveResponseDnsRecordsItem",
    "GetV21DnsReverseResponse",
    "GetV21DnsReverseResponseReverseDnsRecordsItem",
    "GetV21DnsReverseResponseReverseDnsRecordsItemDnsRecordsItem",
    "GetV21DnsReverseResponseReverseDnsRecordsItemDnsTypes",
    "InternalServerErrorBody",
    "NotFoundErrorBody",
    "PostV10BulkwhoisResponse",
    "PostV10BulkwhoisResponseBulkWhoisResponseItem",
    "PostV10BulkwhoisResponseBulkWhoisResponseItemDomainRegistrar",
    "PostV10BulkwhoisResponseBulkWhoisResponseItemRegistrantContact",
    "PostV20DnsBulkLiveResponse",
    "PostV20DnsBulkLiveResponseBulkDnsInfoItem",
    "PostV20DnsBulkLiveResponseBulkDnsInfoItemDnsRecordsItem",
    "PostV20DnsBulkLiveResponseBulkDnsInfoItemDnsTypes",
    "PreconditionFailedErrorBody",
    "RequestTimeoutErrorBody",
    "ServiceUnavailableErrorBody",
    "TooManyRequestsErrorBody",
    "UnauthorizedErrorBody",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .get_v_10_ssl_live_response_ssl_certificates_item_extensions import (
    GetV10SslLiveResponseSslCertificatesItemExtensions,
)
from .get_v_10_ssl_live_response_ssl_certificates_item_issuer import GetV10SslLiveResponseSslCertificatesItemIssuer
from .get_v_10_ssl_live_response_ssl_certificates_item_public_key import (
    GetV10SslLiveResponseSslCertificatesItemPublicKey,
)
from .get_v_10_ssl_live_response_ssl_certificates_item_subject import GetV10SslLiveResponseSslCertificatesItemSubject


class GetV10SslLiveResponseSslCertificatesItem(UniversalBaseModel):
    chain_order: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="chainOrder")] = None
    authentication_type: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="authenticationType")
    ] = None
    validity_start_date: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="validityStartDate")] = (
        None
    )
    validity_end_date: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="validityEndDate")] = None
    serial_number: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="serialNumber")] = None
    signature_algorithm: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="signatureAlgorithm")
    ] = None
    subject: typing.Optional[GetV10SslLiveResponseSslCertificatesItemSubject] = None
    issuer: typing.Optional[GetV10SslLiveResponseSslCertificatesItemIssuer] = None
    public_key: typing_extensions.Annotated[
        typing.Optional[GetV10SslLiveResponseSslCertificatesItemPublicKey], FieldMetadata(alias="publicKey")
    ] = None
    extensions: typing.Optional[GetV10SslLiveResponseSslCertificatesItemExtensions] = None
    pem_raw: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="pemRaw")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .get_v_10_asn_whois_response_administrative_contacts_item import GetV10AsnWhoisResponseAdministrativeContactsItem
from .get_v_10_asn_whois_response_as_blocks_item import GetV10AsnWhoisResponseAsBlocksItem
from .get_v_10_asn_whois_response_aut_nums_item import GetV10AsnWhoisResponseAutNumsItem
from .get_v_10_asn_whois_response_organization import GetV10AsnWhoisResponseOrganization
from .get_v_10_asn_whois_response_technical_contacts_item import GetV10AsnWhoisResponseTechnicalContactsItem


class GetV10AsnWhoisResponse(UniversalBaseModel):
    status: typing.Optional[bool] = None
    as_number: typing.Optional[str] = None
    query_time: typing.Optional[str] = None
    whois_server: typing.Optional[str] = None
    as_blocks: typing.Optional[typing.List[GetV10AsnWhoisResponseAsBlocksItem]] = None
    aut_nums: typing.Optional[typing.List[GetV10AsnWhoisResponseAutNumsItem]] = None
    organization: typing.Optional[GetV10AsnWhoisResponseOrganization] = None
    administrative_contacts: typing.Optional[typing.List[GetV10AsnWhoisResponseAdministrativeContactsItem]] = None
    technical_contacts: typing.Optional[typing.List[GetV10AsnWhoisResponseTechnicalContactsItem]] = None
    whois_raw_response: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class GetV10IpWhoisResponseInetNumsItem(UniversalBaseModel):
    start_ip: typing.Optional[str] = None
    end_ip: typing.Optional[str] = None
    cidr: typing.Optional[typing.List[str]] = None
    net_name: typing.Optional[str] = None
    net_handle: typing.Optional[str] = None
    status: typing.Optional[str] = None
    organization: typing.Optional[str] = None
    date_created: typing.Optional[str] = None
    date_updated: typing.Optional[str] = None
    source: typing.Optional[str] = None
    parents: typing.Optional[typing.List[str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .get_v_20_dns_historical_response_historical_dns_records_item import (
    GetV20DnsHistoricalResponseHistoricalDnsRecordsItem,
)


class GetV20DnsHistoricalResponse(UniversalBaseModel):
    total_records: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalRecords")] = None
    total_pages: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalPages")] = None
    current_page: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="currentPage")] = None
    historical_dns_records: typing_extensions.Annotated[
        typing.Optional[typing.List[GetV20DnsHistoricalResponseHistoricalDnsRecordsItem]],
        FieldMetadata(alias="historicalDnsRecords"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    BadRequestErrorBody,
    ContentTooLargeErrorBody,
    ForbiddenErrorBody,
    GatewayTimeoutErrorBody,
    GetV10AsnWhoisResponse,
    GetV10AsnWhoisResponseAdministrativeContactsItem,
    GetV10AsnWhoisResponseAsBlocksItem,
    GetV10AsnWhoisResponseAutNumsItem,
    GetV10AsnWhoisResponseOrganization,
    GetV10AsnWhoisResponseTechnicalContactsItem,
    GetV10DomainAvailabilityResponse,
    GetV10DomainAvailabilityResponseDomainAvailableResponseItem,
    GetV10IpWhoisResponse,
    GetV10IpWhoisResponseAbuseContactsItem,
    GetV10IpWhoisResponseInetNumsItem,
    GetV10IpWhoisResponseOrganization,
    GetV10IpWhoisResponseTechnicalContactsItem,
    GetV10SslLiveResponse,
    GetV10SslLiveResponseSslCertificatesItem,
    GetV10SslLiveResponseSslCertificatesItemExtensions,
    GetV10SslLiveResponseSslCertificatesItemExtensionsAuthorityInfoAccess,
    GetV10SslLiveResponseSslCertificatesItemExtensionsCertificatePoliciesItem,
    GetV10SslLiveResponseSslCertificatesItemExtensionsSubjectAlternativeNames,
    GetV10SslLiveResponseSslCertificatesItemIssuer,
    GetV10SslLiveResponseSslCertificatesItemPublicKey,
    GetV10SslLiveResponseSslCertificatesItemSubject,
    GetV10WhoisResponse,
    GetV10WhoisResponseRegistryData,
    GetV10WhoisResponseStatus,
    GetV10WhoisResponseWhoisDomainsHistoricalItem,
    GetV10WhoisResponseWhoisDomainsHistoricalItemRegistryData,
    GetV20DnsHistoricalResponse,
    GetV20DnsHistoricalResponseHistoricalDnsRecordsItem,
    GetV20DnsHistoricalResponseHistoricalDnsRecordsItemDnsRecordsItem,
    GetV20DnsLiveResponse,
    GetV20DnsLiveResponseDnsRecordsItem,
    GetV21DnsReverseResponse,
    GetV21DnsReverseResponseReverseDnsRecordsItem,
    GetV21DnsReverseResponseReverseDnsRecordsItemDnsRecordsItem,
    GetV21DnsReverseResponseReverseDnsRecordsItemDnsTypes,
    InternalServerErrorBody,
    NotFoundErrorBody,
    PostV10BulkwhoisResponse,
    PostV10BulkwhoisResponseBulkWhoisResponseItem,
    PostV10BulkwhoisResponseBulkWhoisResponseItemDomainRegistrar,
    PostV10BulkwhoisResponseBulkWhoisResponseItemRegistrantContact,
    PostV20DnsBulkLiveResponse,
    PostV20DnsBulkLiveResponseBulkDnsInfoItem,
    PostV20DnsBulkLiveResponseBulkDnsInfoItemDnsRecordsItem,
    PostV20DnsBulkLiveResponseBulkDnsInfoItemDnsTypes,
    PreconditionFailedErrorBody,
    RequestTimeoutErrorBody,
    ServiceUnavailableErrorBody,
    TooManyRequestsErrorBody,
    UnauthorizedErrorBody,
)
from .errors import (
    BadRequestError,
    ContentTooLargeError,
    ForbiddenError,
    GatewayTimeoutError,
    InternalServerError,
    NotFoundError,
    PreconditionFailedError,
    RequestTimeoutError,
    ServiceUnavailableError,
    TooManyRequestsError,
    UnauthorizedError,
)
from .client import AsyncWhoisfreaksApi, WhoisfreaksApi
from .environment import WhoisfreaksApiEnvironment
from .version import __version__

__all__ = [
    "AsyncWhoisfreaksApi",
    "BadRequestError",
    "BadRequestErrorBody",
    "ContentTooLargeError",
    "ContentTooLargeErrorBody",
    "ForbiddenError",
    "ForbiddenErrorBody",
    "GatewayTimeoutError",
    "GatewayTimeoutErrorBody",
    "GetV10AsnWhoisResponse",
    "GetV10AsnWhoisResponseAdministrativeContactsItem",
    "GetV10AsnWhoisResponseAsBlocksItem",
    "GetV10AsnWhoisResponseAutNumsItem",
    "GetV10AsnWhoisResponseOrganization",
    "GetV10AsnWhoisResponseTechnicalContactsItem",
    "GetV10DomainAvailabilityResponse",
    "GetV10DomainAvailabilityResponseDomainAvailableResponseItem",
    "GetV10IpWhoisResponse",
    "GetV10IpWhoisResponseAbuseContactsItem",
    "GetV10IpWhoisResponseInetNumsItem",
    "GetV10IpWhoisResponseOrganization",
    "GetV10IpWhoisResponseTechnicalContactsItem",
    "GetV10SslLiveResponse",
    "GetV10SslLiveResponseSslCertificatesItem",
    "GetV10SslLiveResponseSslCertificatesItemExtensions",
    "GetV10SslLiveResponseSslCertificatesItemExtensionsAuthorityInfoAccess",
    "GetV10SslLiveResponseSslCertificatesItemExtensionsCertificatePoliciesItem",
    "GetV10SslLiveResponseSslCertificatesItemExtensionsSubjectAlternativeNames",
    "GetV10SslLiveResponseSslCertificatesItemIssuer",
    "GetV10SslLiveResponseSslCertificatesItemPublicKey",
    "GetV10SslLiveResponseSslCertificatesItemSubject",
    "GetV10WhoisResponse",
    "GetV10WhoisResponseRegistryData",
    "GetV10WhoisResponseStatus",
    "GetV10WhoisResponseWhoisDomainsHistoricalItem",
    "GetV10WhoisResponseWhoisDomainsHistoricalItemRegistryData",
    "GetV20DnsHistoricalResponse",
    "GetV20DnsHistoricalResponseHistoricalDnsRecordsItem",
    "GetV20DnsHistoricalResponseHistoricalDnsRecordsItemDnsRecordsItem",
    "GetV20DnsLiveResponse",
    "GetV20DnsLiveResponseDnsRecordsItem",
    "GetV21DnsReverseResponse",
    "GetV21DnsReverseResponseReverseDnsRecordsItem",
    "GetV21DnsReverseResponseReverseDnsRecordsItemDnsRecordsItem",
    "GetV21DnsReverseResponseReverseDnsRecordsItemDnsTypes",
    "InternalServerError",
    "InternalServerErrorBody",
    "NotFoundError",
    "NotFoundErrorBody",
    "PostV10BulkwhoisResponse",
    "PostV10BulkwhoisResponseBulkWhoisResponseItem",
    "PostV10BulkwhoisResponseBulkWhoisResponseItemDomainRegistrar",
    "PostV10BulkwhoisResponseBulkWhoisResponseItemRegistrantContact",
    "PostV20DnsBulkLiveResponse",
    "PostV20DnsBulkLiveResponseBulkDnsInfoItem",
    "PostV20DnsBulkLiveResponseBulkDnsInfoItemDnsRecordsItem",
    "PostV20DnsBulkLiveResponseBulkDnsInfoItemDnsTypes",
    "PreconditionFailedError",
    "PreconditionFailedErrorBody",
    "RequestTimeoutError",
    "RequestTimeoutErrorBody",
    "ServiceUnavailableError",
    "ServiceUnavailableErrorBody",
    "TooManyRequestsError",
    "TooManyRequestsErrorBody",
    "UnauthorizedError",
    "UnauthorizedErrorBody",
    "WhoisfreaksApi",
    "WhoisfreaksApiEnvironment",
    "__version__",
]
